/*************************************************************************\
*                  LCD - Liquid Crystal Display                           *
*-------------------------------------------------------------------------*
* Description : Header file for programming of LCD display                *
*               based on HITACHI controller HD44780.                      *
*-------------------------------------------------------------------------*
*   Instruction     D7  D6  D5  D4  D3  D2  D1  D0                        *
*   ==============================================                        *
*   Display clear   0   0   0   0   0   0   0   1                         *
*   Cursor home     0   0   0   0   0   0   1   *                         *
*   Entry Mode Set  0   0   0   0   0   1  I/D  S                         *
*   Display On/Off  0   0   0   0   1   D   C   B                         *
*   Curs/Disp shift 0   0   0   1  S/C R/L  *   *                         *
*   Function Set    0   0   1   DL  N   F   *   *                         *
*   CG RAM addr set 0   1   ---------Acg---------                         *
*   DD RAM addr set 1   -------------Add---------                         *
*                                                                         *
*   Meaning:                                                              *
*   *     - nonvalid bit                                                  *
*   Acg   - CG RAM address (CHARACTER GENERATOR)                          *
*   Add   - DD RAM address (DATA DISPLAY)                                 *
*   AC    - adress counter                                                *
*                                                                         *
*   I/D   - 1-increment, 0-decrement                                      *
*   S     - 1-display shift, 0-no display shift                           *
*   D     - 1-display ON, 0-display OFF                                   *
*   C     - 1-cursor ON, 0-cursor OFF                                     *
*   B     - 1-blink ON, 0-blink OFF                                       *
*   S/C   - 1-display shift, 0-cursor movement                            *
*   R/L   - 1-right shift, 0-left shift                                   *
*   DL    - 1-8 bits data transfer, 0-4 bits data transfer                *
*   N     - 1-1/16 duty, 0-1/8 or 1/11 duty                               *
*   F     - 1-5x10 dot matrix, 0-5x7 dot matrix                           *
*   BF    - 1-internal operation in progress, 0-display ready             *
*                                                                         *
\*************************************************************************/
#ifndef __LCD_H
#define __LCD_H

// --- LCD is attached to the following CPU pins --- //

#ifndef SDCC
sfr	P1=0x90;
sfr P3=0xB0;

sbit LCD_RS = P1^0;                   // register select
sbit LCD_RW = P1^1;                   // read/write
sbit LCD_EN = P1^2;                   // chip enable
sbit LCD_BF = P1^7;                   // read busy flag LCD D7 bit
sbit ButtonR= P3^2;                   // INT0
sbit ButtonL= P3^3;                   // INT1
#else
sfr at 0x80 P0;
sfr at 0x90 P1;

sbit at 0x90 LCD_RS;	//P1_0 ;
sbit at 0x91 LCD_RW;	//P1_1 ;
sbit at 0x92 LCD_EN;	//P1_2 ;
sbit at 0x97 LCD_BF;	//P1_3 ;
sbit at 0xB2 ButtonR;	//INT0 ;
sbit at 0xB3 ButtonL;	//INT0 ;
#endif

#define LCD_PORT P1                   // LCD data bus [7..0]

// --- LCD commands --- //

#define cmd_lcd_init            0x38

#define cmd_lcd_clear           0x01  
#define cmd_lcd_home            0x02  

#define cmd_cur_shift_on        0x06  
#define cmd_cur_shift_off       0x07  

#define cmd_lcd_on              0x0E  
#define cmd_lcd_off             0x0A  

#define cmd_cur_on              0x0E  
#define cmd_cur_off             0x0C  

#define cmd_cur_blink_on        0x0F  
#define cmd_cur_blink_off       0x0E  

#define cmd_cur_left            0x10  
#define cmd_cur_right           0x14  

#define cmd_scr_left            0x18  
#define cmd_scr_right           0x1C  


void DelayUs(unsigned char i);
void DelayMs(unsigned int i);

void LCD_Init( void );
void LCD_SendVal( unsigned char val, bit RS );
#define LCD_SendCmd( val )  LCD_SendVal( val, 0 )  // send command
#define LCD_SendData( val ) LCD_SendVal( val, 1 )  // send data

void LCD_Putch( unsigned char val );
void LCD_Puts( unsigned char *str );

void LCD_Wait( void );

void LCD_Cursor_YX( unsigned char row, unsigned char column );

#endif


